@@ -286,9 +286,9 @@ class Esme(object):
                             except:
                                 pass
                     elif p.command == 'enquire_link':
-                            self._enquire_link_received(p)
+                        self._enquire_link_received(p)
                     elif p.command == 'enquire_link_resp':
-                            pass
+                        pass
                     else:
                         self.queue.put(p)
 
@@ -346,20 +346,6 @@ class Server(object):
                         pass
                 time.sleep(2)
 
-    def __del__(self):
-        """Disconnect when server object is destroyed"""
-
-        for client in self.clients:
-            if client.socket is not None:
-                try:
-                    client.unbind()
-                except (exceptions.PDUError, exceptions.ConnectionError) as e:
-                    if len(getattr(e, 'args', tuple())) > 1:
-                        logging.warning('({0}) {1}. Ignored'.format(e.args[1], e.args[0]))
-                    else:
-                        logging.warning('{0}. Ignored'.format(e))
-        self.down()
-
     def up(self):
         """Start listening"""
 
@@ -392,6 +378,16 @@ class Server(object):
 
         logging.info('Disconnecting...')
 
+        for client in self.clients:
+            if client.socket is not None:
+                try:
+                    client.unbind()
+                except (exceptions.PDUError, exceptions.ConnectionError) as e:
+                    if len(getattr(e, 'args', tuple())) > 1:
+                        logging.warning('({0}) {1}. Ignored'.format(e.args[1], e.args[0]))
+                    else:
+                        logging.warning('{0}. Ignored'.format(e))
+
         if self._socket is not None:
             try:
                 self._socket.close()
